@@ -524,7 +524,10 @@ ghw_read_type (struct ghw_handler *h)
 	    e->wkt = ghw_wkt_unknown;
 	    e->name = ghw_read_strid (h);
 	    if (ghw_read_uleb128 (h, (uint32_t *)&e->nbr) != 0)
-	      return -1;
+		{
+		free(e); /* cppcheck */
+	      	return -1;
+		}
 	    e->lits = (const char **) calloc (1, e->nbr * sizeof (char *));
 	    if (h->flag_verbose > 1)
 	      printf ("enum %s:", e->name);
@@ -565,16 +568,23 @@ ghw_read_type (struct ghw_handler *h)
 	      ph->nbr_units = 0;
 	    else
 	      {
-		int ix;
+		unsigned int ix;
 
 		if (ghw_read_uleb128 (h, &ph->nbr_units) != 0)
-		  return -1;
+			{
+			free(ph); /* cppcheck */
+		  	return -1;
+			}
 		ph->units = calloc (ph->nbr_units, sizeof (struct ghw_unit));
 		for (ix = 0; ix < ph->nbr_units; ix++)
 		  {
 		    ph->units[ix].name = ghw_read_strid (h);
 		    if (ghw_read_lsleb128 (h, &ph->units[ix].val) < 0)
-		      return -1;
+			{
+			free(ph->units); /* missed by cppcheck */
+			free(ph); /* missed by cppcheck */
+		      	return -1;
+			}
 		  }
 	      }
 	    if (h->flag_verbose > 1)
@@ -606,7 +616,10 @@ ghw_read_type (struct ghw_handler *h)
 	    arr->name = ghw_read_strid (h);
 	    arr->el = ghw_read_typeid (h);
 	    if (ghw_read_uleb128 (h, (uint32_t *)&arr->nbr_dim) != 0)
-	      return -1;
+		{
+		free(arr); /* cppcheck */
+	      	return -1;
+		}
 	    arr->dims = (union ghw_type **)
 	      calloc (arr->nbr_dim, sizeof (union ghw_type *));
 	    for (j = 0; j < arr->nbr_dim; j++)
@@ -650,7 +663,10 @@ ghw_read_type (struct ghw_handler *h)
 	    rec->kind = t;
 	    rec->name = ghw_read_strid (h);
 	    if (ghw_read_uleb128 (h, (uint32_t *)&rec->nbr_fields) != 0)
-	      return -1;
+		{
+		free(rec); /* cppcheck */
+	      	return -1;
+		}
 	    rec->el = calloc
 	      (rec->nbr_fields, sizeof (struct ghw_record_element));
 	    nbr_el = 0;
@@ -713,6 +729,8 @@ ghw_read_wk_types (struct ghw_handler *h)
 void
 ghw_disp_typename (struct ghw_handler *h, union ghw_type *t)
 {
+(void) h;
+
   printf ("%s", t->common.name);
 }
 
@@ -732,7 +750,7 @@ ghw_read_signal (struct ghw_handler *h, unsigned int *sigs, union ghw_type *t)
 	if (ghw_read_uleb128 (h, &sig_el) < 0)
 	  return -1;
 	*sigs = sig_el;
-	if (sig_el >= h->nbr_sigs)
+	if (((int)sig_el) >= h->nbr_sigs)
 	  abort ();
 	if (h->sigs[sig_el].type == NULL)
 	  h->sigs[sig_el].type = ghw_get_base_type (t);
@@ -757,7 +775,7 @@ ghw_read_signal (struct ghw_handler *h, unsigned int *sigs, union ghw_type *t)
       {
 	int i;
 	int off;
-	
+
 	off = 0;
 	for (i = 0; i < t->rec.nbr_fields; i++)
 	  {
@@ -1051,7 +1069,7 @@ ghw_disp_hie (struct ghw_handler *h, struct ghw_hie *top)
 
   hie = top;
   indent = 0;
-  
+
   while (1)
     {
       for (i = 0; i < indent; i++)
@@ -1120,6 +1138,8 @@ ghw_disp_hie (struct ghw_handler *h, struct ghw_hie *top)
 int
 ghw_read_eoh (struct ghw_handler *h)
 {
+(void) h;
+
   return 0;
 }
 
@@ -1225,7 +1245,7 @@ ghw_read_cycle_cont (struct ghw_handler *h, int *list)
   while (1)
     {
       uint32_t d;
-      
+
       /* Read delta to next signal.  */
       if (ghw_read_uleb128 (h, &d) < 0)
 	return -1;
@@ -1242,13 +1262,13 @@ ghw_read_cycle_cont (struct ghw_handler *h, int *list)
 	  if (h->sigs[i].type != NULL)
 	    d--;
 	}
-      
+
       if (ghw_read_signal_value (h, &h->sigs[i]) < 0)
 	return -1;
       if (list_p)
 	*list_p++ = i;
     }
-  
+
   if (list_p)
     *list_p = 0;
   return 0;
@@ -1403,7 +1423,7 @@ ghw_read_directory (struct ghw_handler *h)
     return -1;
 
   nbr_entries = ghw_get_i32 (h, &hdr[4]);
-  
+
   if (h->flag_verbose)
     printf ("Directory (%d entries):\n", nbr_entries);
 
@@ -1437,7 +1457,7 @@ ghw_read_tailer (struct ghw_handler *h)
     return -1;
 
   pos = ghw_get_i32 (h, &hdr[4]);
-  
+
   if (h->flag_verbose)
     printf ("Tailer: directory at %d\n", pos);
   return 0;
@@ -1471,7 +1491,7 @@ ghw_read_sm_hdr (struct ghw_handler *h, int *list)
       res = ghw_read_cycle_cont (h, list);
       if (res < 0)
 	return res;
-      
+
       return ghw_res_cycle;
     }
   else if (memcmp (hdr, "DIR", 4) == 0)
@@ -1482,7 +1502,7 @@ ghw_read_sm_hdr (struct ghw_handler *h, int *list)
     {
       res = ghw_read_tailer (h);
     }
-  else 
+  else
     {
       fprintf (stderr, "unknown GHW section %c%c%c%c\n",
 	       hdr[0], hdr[1], hdr[2], hdr[3]);
@@ -1525,7 +1545,7 @@ ghw_read_sm (struct ghw_handler *h, enum ghw_sm_type *sm)
 	    printf ("Time is "GHWLLD" fs\n", h->snap_time);
 	  if (0)
 	    ghw_disp_values (h);
-	  
+
 	  res = ghw_read_cycle_next (h);
 	  if (res < 0)
 	    return res;
@@ -1558,13 +1578,13 @@ ghw_read_cycle (struct ghw_handler *h)
       res = ghw_read_cycle_cont (h, NULL);
       if (res < 0)
 	return res;
-      
+
       if (0)
 	printf ("Time is "GHWLLD" fs\n", h->snap_time);
       if (0)
 	ghw_disp_values (h);
-      
-	      
+
+
       res = ghw_read_cycle_next (h);
       if (res < 0)
 	return res;
@@ -1608,7 +1628,7 @@ ghw_read_dump (struct ghw_handler *h)
 	{
 	  res = ghw_read_tailer (h);
 	}
-      else 
+      else
 	{
 	  fprintf (stderr, "unknown GHW section %c%c%c%c\n",
 		   hdr[0], hdr[1], hdr[2], hdr[3]);
@@ -1636,7 +1656,7 @@ int
 ghw_read_section (struct ghw_handler *h)
 {
   unsigned char hdr[4];
-  int i;
+  unsigned int i;
 
   if (fread (hdr, sizeof (hdr), 1, h->stream) != 1)
     {
@@ -1645,7 +1665,7 @@ ghw_read_section (struct ghw_handler *h)
       else
 	return -1;
     }
-  
+
   for (i = 1; i < sizeof (ghw_sections) / sizeof (*ghw_sections); i++)
     if (memcmp (hdr, ghw_sections[i].name, 4) == 0)
       return i;
@@ -1733,7 +1753,7 @@ ghw_disp_type (struct ghw_handler *h, union ghw_type *t)
     case ghdl_rtik_type_p32:
     case ghdl_rtik_type_p64:
       {
-	int i;
+	unsigned int i;
 
 	struct ghw_type_physical *p = &t->ph;
 	printf ("type %s is range <> units\n", p->name);
