@@ -1,5 +1,5 @@
-/* 
- * Copyright (c) Tony Bybell 1999-2008.
+/*
+ * Copyright (c) Tony Bybell 1999-2014.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -16,20 +16,103 @@
 #include "analyzer.h"
 #include "currenttime.h"
 
+static void gtkwave_strrev(char *p)
+{
+char *q = p;
+while(q && *q) ++q;
+for(--q; p < q; ++p, --q)
+        *p = *p ^ *q,
+        *q = *p ^ *q,
+        *p = *p ^ *q;
+}
+
+
+char *make_bijective_marker_id_string(char *buf, unsigned int value)
+{
+char *pnt = buf;
+
+value++; /* bijective values start at one */
+while (value)
+        {
+        value--;
+        *(pnt++) = (char)('A' + value % ('Z'-'A'+1));
+        value = value / ('Z'-'A'+1);
+        }
+
+*pnt = 0;
+gtkwave_strrev(buf);
+return(buf);
+}
+
+
+unsigned int bijective_marker_id_string_hash(char *so)
+{
+unsigned int val=0;
+int i;
+int len = strlen(so);
+char sn[16];
+char *s = sn;
+
+strcpy(sn, so);
+gtkwave_strrev(sn);
+
+s += len;
+for(i=0;i<len;i++)
+        {
+	char c = toupper(*(--s));
+	if((c < 'A') || (c > 'Z')) break;
+        val *= ('Z'-'A'+1);
+        val += ((unsigned char)c) - ('A' - 1);
+        }
+
+val--; /* bijective values start at one so decrement */
+return(val);
+}
+
+
+unsigned int bijective_marker_id_string_len(char *s)
+{
+int len = 0;
+
+while(*s)
+	{
+	char c = toupper(*s);
+	if((c >= 'A') && (c <= 'Z'))
+		{
+		len++;
+		s++;
+		continue;
+		}
+		else
+		{
+		break;
+		}
+	}
+
+return(len);
+}
+
+
 static void str_change_callback(GtkWidget *entry, gpointer which)
 {
 G_CONST_RETURN gchar *entry_text;
 int i;
+uint32_t hashmask =  WAVE_NUM_NAMED_MARKERS;
+hashmask |= hashmask >> 1;   
+hashmask |= hashmask >> 2;
+hashmask |= hashmask >> 4;
+hashmask |= hashmask >> 8;
+hashmask |= hashmask >> 16;
 
-i = ((int) (((long) which) & 31L)) % 26;
+i = ((int) (((long) which) & hashmask)) % WAVE_NUM_NAMED_MARKERS;
 GLOBALS->dirty_markerbox_c_1 = 1;
- 
+
 entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
 if(entry_text && strlen(entry_text))
 	{
 	if(GLOBALS->shadow_marker_names[i])
 		{
-		free_2(GLOBALS->shadow_marker_names[i]); 
+		free_2(GLOBALS->shadow_marker_names[i]);
 		}
 
 	GLOBALS->shadow_marker_names[i] = strdup_2(entry_text);
@@ -38,7 +121,7 @@ if(entry_text && strlen(entry_text))
 	{
 	if(GLOBALS->shadow_marker_names[i])
 		{
-		free_2(GLOBALS->shadow_marker_names[i]); 
+		free_2(GLOBALS->shadow_marker_names[i]);
 		GLOBALS->shadow_marker_names[i] = NULL;
 		}
 	}
@@ -48,16 +131,22 @@ static void str_enter_callback(GtkWidget *entry, gpointer which)
 {
 G_CONST_RETURN gchar *entry_text;
 int i;
+uint32_t hashmask =  WAVE_NUM_NAMED_MARKERS;
+hashmask |= hashmask >> 1;   
+hashmask |= hashmask >> 2;
+hashmask |= hashmask >> 4;
+hashmask |= hashmask >> 8;
+hashmask |= hashmask >> 16;
 
-i = ((int) (((long) which) & 31L)) % 26;
+i = ((int) (((long) which) & hashmask)) % WAVE_NUM_NAMED_MARKERS;
 GLOBALS->dirty_markerbox_c_1 = 1;
- 
+
 entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
 if(entry_text && strlen(entry_text))
 	{
 	if(GLOBALS->shadow_marker_names[i])
 		{
-		free_2(GLOBALS->shadow_marker_names[i]); 
+		free_2(GLOBALS->shadow_marker_names[i]);
 		}
 
 	GLOBALS->shadow_marker_names[i] = strdup_2(entry_text);
@@ -69,26 +158,32 @@ if(entry_text && strlen(entry_text))
 	{
 	if(GLOBALS->shadow_marker_names[i])
 		{
-		free_2(GLOBALS->shadow_marker_names[i]); 
+		free_2(GLOBALS->shadow_marker_names[i]);
 		GLOBALS->shadow_marker_names[i] = NULL;
 		}
 	}
 }
 
 
-
-
 static void change_callback(GtkWidget *widget, gpointer which)
 {
+(void)widget;
+
 GtkWidget *entry;
 TimeType temp;
 G_CONST_RETURN gchar *entry_text;
 char buf[49];
 int i;
 int ent_idx;
+uint32_t hashmask =  WAVE_NUM_NAMED_MARKERS;
+hashmask |= hashmask >> 1;   
+hashmask |= hashmask >> 2;
+hashmask |= hashmask >> 4;
+hashmask |= hashmask >> 8;
+hashmask |= hashmask >> 16;
+
+ent_idx = ((int) (((long) which) & hashmask)) % WAVE_NUM_NAMED_MARKERS;
 
-ent_idx = ((int) (((long) which) & 31L)) % 26;
- 
 entry=GLOBALS->entries_markerbox_c_1[ent_idx];
 
 entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
@@ -103,9 +198,9 @@ temp=unformat_time(entry_text, GLOBALS->time_dimension);
 temp -= GLOBALS->global_time_offset;
 if((temp<GLOBALS->tims.start)||(temp>GLOBALS->tims.last)) goto failure;
 
-for(i=0;i<26;i++)
+for(i=0;i<WAVE_NUM_NAMED_MARKERS;i++)
         {
-        if(temp==GLOBALS->shadow_markers_markerbox_c_1[i]) 
+        if(temp==GLOBALS->shadow_markers_markerbox_c_1[i])
 		{
 		if(i!=ent_idx)
 			{
@@ -126,6 +221,8 @@ return;
 
 static void enter_callback(GtkWidget *widget, gpointer which)
 {
+(void)widget;
+
 GtkWidget *entry;
 /* TimeType *modify; */ /* scan-build */
 TimeType temp;
@@ -133,9 +230,15 @@ G_CONST_RETURN gchar *entry_text;
 char buf[49];
 int i;
 int ent_idx;
+uint32_t hashmask =  WAVE_NUM_NAMED_MARKERS;
+hashmask |= hashmask >> 1;   
+hashmask |= hashmask >> 2;
+hashmask |= hashmask >> 4;
+hashmask |= hashmask >> 8;
+hashmask |= hashmask >> 16;
+
+ent_idx = ((int) (((long) which) & hashmask)) % WAVE_NUM_NAMED_MARKERS;
 
-ent_idx = ((int) (((long) which) & 31L)) % 26;
- 
 entry=GLOBALS->entries_markerbox_c_1[ent_idx];
 
 entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
@@ -146,7 +249,7 @@ temp=unformat_time(entry_text, GLOBALS->time_dimension);
 temp -= GLOBALS->global_time_offset;
 if((temp<GLOBALS->tims.start)||(temp>GLOBALS->tims.last)) goto failure;
 
-for(i=0;i<26;i++)
+for(i=0;i<WAVE_NUM_NAMED_MARKERS;i++)
         {
         if(temp==GLOBALS->shadow_markers_markerbox_c_1[i]) goto failure;
         }
@@ -175,10 +278,13 @@ gtk_entry_set_text (GTK_ENTRY (entry), buf);
 
 static void ok_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)widget;
+(void)nothing;
+
 if(GLOBALS->dirty_markerbox_c_1)
 	{
 	int i;
-	for(i=0;i<26;i++) 
+	for(i=0;i<WAVE_NUM_NAMED_MARKERS;i++)
 		{
 		GLOBALS->named_markers[i]=GLOBALS->shadow_markers_markerbox_c_1[i];
 		if(GLOBALS->marker_names[i]) free_2(GLOBALS->marker_names[i]);
@@ -199,8 +305,11 @@ if(GLOBALS->dirty_markerbox_c_1)
 
 static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)widget;
+(void)nothing;
+
 int i;
-  for(i=0;i<26;i++)
+  for(i=0;i<WAVE_NUM_NAMED_MARKERS;i++)
 	{
 	if(GLOBALS->marker_names[i]) free_2(GLOBALS->marker_names[i]);
   	GLOBALS->marker_names[i] = GLOBALS->shadow_marker_names[i];
@@ -218,13 +327,13 @@ void markerbox(char *title, GtkSignalFunc func)
     GtkWidget *vbox, *hbox, *vbox_g, *label;
     GtkWidget *button1, *button2, *scrolled_win, *frame, *separator;
     GtkWidget *table;
-    char labtitle[2]={0,0};
+    char labtitle[16];
     int i;
 
     GLOBALS->cleanup_markerbox_c_4=func;
     GLOBALS->dirty_markerbox_c_1=0;
 
-    for(i=0;i<26;i++) 
+    for(i=0;i<WAVE_NUM_NAMED_MARKERS;i++)
 	{
 	GLOBALS->shadow_markers_markerbox_c_1[i] = GLOBALS->named_markers[i];
 	GLOBALS->shadow_marker_names[i] = strdup_2(GLOBALS->marker_names[i]);
@@ -266,7 +375,7 @@ void markerbox(char *title, GtkSignalFunc func)
     gtk_container_add (GTK_CONTAINER (frame), scrolled_win);
     gtk_container_add (GTK_CONTAINER (vbox), frame);
 
-    for(i=0;i<26;i++)
+    for(i=0;i<WAVE_NUM_NAMED_MARKERS;i++)
     {
     char buf[49];
 
@@ -277,7 +386,8 @@ void markerbox(char *title, GtkSignalFunc func)
         gtk_box_pack_start (GTK_BOX (vbox_g), separator, TRUE, TRUE, 0);
 	}
 
-    labtitle[0]='A'+i;
+
+    make_bijective_marker_id_string(labtitle, i);
     label=gtk_label_new(labtitle);
     gtk_widget_show (label);
     gtk_box_pack_start (GTK_BOX (vbox_g), label, TRUE, TRUE, 0);
