@@ -1,4 +1,4 @@
-/* 
+/*
  * Copyright (c) Tony Bybell 1999-2013.
  *
  * This program is free software; you can redistribute it and/or
@@ -20,14 +20,14 @@
 #ifdef WAVE_USE_GTK2
 #define WV_STRACE_CURWIN(x) g_object_set_data(G_OBJECT(x), WV_STRACE_CTX, (gpointer)GLOBALS->strace_ctx)
 #else
-#define WV_STRACE_CURWIN
+#define WV_STRACE_CURWIN(x) do { } while(0 && (x))
 #endif
 
 /* need to do this at top of every entry point function where a signal is connected */
 #ifdef WAVE_USE_GTK2
 #define GET_WV_STRACE_CURWIN(x) GLOBALS->strace_ctx=g_object_get_data(G_OBJECT(x), WV_STRACE_CTX)
 #else
-#define GET_WV_STRACE_CURWIN
+#define GET_WV_STRACE_CURWIN(x) do { } while(0 && (x))
 #endif
 
 static char *logical[]=
@@ -213,7 +213,7 @@ static void start_clicked(GtkWidget *widget, gpointer which)
 GET_WV_STRACE_CURWIN(widget);
 
 GLOBALS->strace_ctx->mark_idx_start=((struct item_mark_string*)which)->idx;
-if (GLOBALS->strace_ctx->mark_idx_start<0 || GLOBALS->strace_ctx->mark_idx_start>=(sizeof(item_mark_start_strings)/sizeof(struct item_mark_string)))
+if (GLOBALS->strace_ctx->mark_idx_start<0 || GLOBALS->strace_ctx->mark_idx_start>=(int)(sizeof(item_mark_start_strings)/sizeof(struct item_mark_string)))
 	{
 	fprintf(stderr, "Internal error: GLOBALS->mark_idx_start out of range %d\n", GLOBALS->strace_ctx->mark_idx_start);
 	exit(255);
@@ -226,7 +226,7 @@ static void end_clicked(GtkWidget *widget, gpointer which)
 GET_WV_STRACE_CURWIN(widget);
 
 GLOBALS->strace_ctx->mark_idx_end=((struct item_mark_string*)which)->idx;
-if (GLOBALS->strace_ctx->mark_idx_end<0 || GLOBALS->strace_ctx->mark_idx_end>=(sizeof(item_mark_end_strings)/sizeof(struct item_mark_string)))
+if (GLOBALS->strace_ctx->mark_idx_end<0 || GLOBALS->strace_ctx->mark_idx_end>=(int)(sizeof(item_mark_end_strings)/sizeof(struct item_mark_string)))
 	{
 	fprintf(stderr, "Internal error: GLOBALS->mark_idx_end out of range %d\n",GLOBALS->strace_ctx->mark_idx_end);
 	exit(255);
@@ -265,6 +265,8 @@ for(i=0;i<len;i++)
 
 static void forwards_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)nothing;
+
 GET_WV_STRACE_CURWIN(widget);
 
 /* no cleanup necessary, but do real search */
@@ -274,6 +276,8 @@ strace_search(STRACE_FORWARD);
 
 static void backwards_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)nothing;
+
 GET_WV_STRACE_CURWIN(widget);
 
 /* no cleanup necessary, but do real search */
@@ -283,6 +287,8 @@ strace_search(STRACE_BACKWARD);
 
 static void mark_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)nothing;
+
 GET_WV_STRACE_CURWIN(widget);
 
 DEBUG(printf("Marking..\n"));
@@ -301,6 +307,8 @@ wavearea_configure_event(GLOBALS->wavearea, NULL);
 
 static void clear_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)nothing;
+
 GET_WV_STRACE_CURWIN(widget);
 
 DEBUG(printf("Clearing..\n"));
@@ -317,6 +325,8 @@ wavearea_configure_event(GLOBALS->wavearea, NULL);
 
 static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)nothing;
+
   GET_WV_STRACE_CURWIN(widget);
 
   free_straces();
@@ -340,7 +350,7 @@ if(GLOBALS->strace_ctx->ptr_mark_count_label_strace_c_1)
 void tracesearchbox(const char *title, GtkSignalFunc func, gpointer data)
 {
     GtkWidget *menu, *menuitem, *optionmenu;
-    GSList *group; 
+    GSList *group;
     GtkWidget *entry;
     GtkWidget *vbox, *hbox, *small_hbox, *vbox_g, *label;
     GtkWidget *button1, *button1a, *button1b, *button1c, *button2, *scrolled_win, *frame, *separator;
@@ -354,7 +364,7 @@ void tracesearchbox(const char *title, GtkSignalFunc func, gpointer data)
     /* fix problem where ungrab doesn't occur if button pressed + simultaneous accelerator key occurs */
     if(GLOBALS->in_button_press_wavewindow_c_1) { gdk_pointer_ungrab(GDK_CURRENT_TIME); }
 
-    if(GLOBALS->strace_ctx->straces) 
+    if(GLOBALS->strace_ctx->straces)
 	{
 	gdk_window_raise(GLOBALS->strace_ctx->window_strace_c_10->window);
 	return; /* is already active */
@@ -367,11 +377,11 @@ void tracesearchbox(const char *title, GtkSignalFunc func, gpointer data)
     GLOBALS->strace_ctx->window_strace_c_10 = gtk_window_new(GLOBALS->disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
 
     GLOBALS->strace_windows[GLOBALS->strace_current_window].window_strace_c_10 = gtk_window_new(GLOBALS->disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
-    install_focus_cb(GLOBALS->strace_windows[GLOBALS->strace_current_window].window_strace_c_10, 
+    install_focus_cb(GLOBALS->strace_windows[GLOBALS->strace_current_window].window_strace_c_10,
 		((char *)&GLOBALS->strace_windows[GLOBALS->strace_current_window].window_strace_c_10) - ((char *)GLOBALS));
 
     gtk_window_set_title(GTK_WINDOW (GLOBALS->strace_ctx->window_strace_c_10), title);
-    gtk_widget_set_usize( GTK_WIDGET (GLOBALS->strace_ctx->window_strace_c_10), 420, -1); 
+    gtk_widget_set_usize( GTK_WIDGET (GLOBALS->strace_ctx->window_strace_c_10), 420, -1);
     gtkwave_signal_connect(GTK_OBJECT (GLOBALS->strace_ctx->window_strace_c_10), "delete_event",(GtkSignalFunc) destroy_callback, NULL);
     WV_STRACE_CURWIN(GLOBALS->strace_ctx->window_strace_c_10);
 
@@ -418,7 +428,7 @@ void tracesearchbox(const char *title, GtkSignalFunc func, gpointer data)
 	gtk_box_pack_start (GTK_BOX (vbox), small_hbox, FALSE, FALSE, 0);
 
     scrolled_win = gtk_scrolled_window_new (NULL, NULL);
-    gtk_widget_set_usize( GTK_WIDGET (scrolled_win), -1, 300); 
+    gtk_widget_set_usize( GTK_WIDGET (scrolled_win), -1, 300);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win),
                                       GTK_POLICY_AUTOMATIC,
                                       GTK_POLICY_AUTOMATIC);
@@ -433,7 +443,7 @@ void tracesearchbox(const char *title, GtkSignalFunc func, gpointer data)
     if ((t->flags&(TR_BLANK|TR_ANALOG_BLANK_STRETCH))||(!(t->flags&TR_HIGHLIGHT))||(!(t->name))) continue;
 
     numtraces++;
-    if(numtraces==500) 
+    if(numtraces==500)
 	{
 	status_text("Limiting waveform display search to 500 traces.\n");
 	break;
@@ -496,9 +506,9 @@ void tracesearchbox(const char *title, GtkSignalFunc func, gpointer data)
 
     do		/* add GUI elements for displaying mark count and mark count start/end */
 	{
-	int idx;
+	unsigned int idx;
 	GtkWidget *ptr_mark_start_label, *ptr_mark_end_label;
-	GtkWidget *mark_count_hbox_start,  *mark_count_hbox_end; 
+	GtkWidget *mark_count_hbox_start,  *mark_count_hbox_end;
 	GtkWidget *count_vbox_left, *count_vbox_right, *count_vbox, *count_hbox;
 	GtkWidget *ptr_mark_count_start, *ptr_mark_count_end;
 
@@ -644,7 +654,7 @@ if(GLOBALS->tims.marker<0)
 	basetime=MAX_HISTENT_TIME;
 	}
 	else
-	{	
+	{
 	basetime=GLOBALS->tims.marker;
 	}
 }
@@ -655,10 +665,10 @@ if(GLOBALS->tims.marker<0)
 	basetime=GLOBALS->tims.first;
 	}
 	else
-	{	
+	{
 	basetime=GLOBALS->tims.marker;
 	}
-} 
+}
 
 sttim=GLOBALS->tims.first;
 fintim=GLOBALS->tims.last;
@@ -729,7 +739,7 @@ while(s)
 		if((whichpass)||(GLOBALS->tims.marker>=0)) h=h->next;
 		if(!h) return;
 		s->his.h=h;
-		utt=strace_adjust(h->time,GLOBALS->shift_timebase); tt=utt;		
+		utt=strace_adjust(h->time,GLOBALS->shift_timebase); tt=utt;
 		if(tt < maxbase) maxbase=tt;
 		}
 		else
@@ -759,19 +769,19 @@ while(s)
 	t=s->trace;
 	s->search_result=0;	/* explicitly must set this */
 	GLOBALS->shift_timebase=t->shift;
-	
+
 	if((!t->vector)&&(!(t->n.nd->extvals)))
 		{
-		if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
+		if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase)
 			{
 			s->his.h=bsearch_node(t->n.nd, maxbase - t->shift);
 			while(s->his.h->next && s->his.h->time==s->his.h->next->time) s->his.h=s->his.h->next;
 			}
-		if(t->flags&TR_INVERT)  
+		if(t->flags&TR_INVERT)
                 	{
                         str[0]=AN_STR_INV[s->his.h->v.h_val];
                         }
-                        else   
+                        else
                         {
                         str[0]=AN_STR[s->his.h->v.h_val];
                         }
@@ -781,14 +791,14 @@ while(s)
 			{
 			case ST_DC:
 				break;
-				
+
 			case ST_HIGH:
 				totaltraces++;
-				if((str[0]=='1')||(str[0]=='h')||(str[0]=='H')) s->search_result=1;	
+				if((str[0]=='1')||(str[0]=='h')||(str[0]=='H')) s->search_result=1;
 				break;
 
 			case ST_RISE:
-				if((str[0]=='1')||(str[0]=='h')||(str[0]=='H')) s->search_result=1;	
+				if((str[0]=='1')||(str[0]=='h')||(str[0]=='H')) s->search_result=1;
 				totaltraces++;
 				break;
 
@@ -806,7 +816,7 @@ while(s)
 				totaltraces++;
 				if((str[0]=='z')||(str[0]=='Z'))
  					s->search_result=1;
-				break;				
+				break;
 
 			case ST_X:
 				totaltraces++;
@@ -817,7 +827,7 @@ while(s)
 				totaltraces++;
 				s->search_result=1;
 				break;
-		
+
 			case ST_STRING:
 				totaltraces++;
 				if(s->string)
@@ -838,7 +848,7 @@ while(s)
 
 		if(t->vector)
 			{
-			if(strace_adjust(s->his.v->time,GLOBALS->shift_timebase)!=maxbase) 
+			if(strace_adjust(s->his.v->time,GLOBALS->shift_timebase)!=maxbase)
 				{
 				s->his.v=bsearch_vector(t->n.vec, maxbase - t->shift);
 				while(s->his.v->next && s->his.v->time==s->his.v->next->time) s->his.v=s->his.v->next;
@@ -847,7 +857,7 @@ while(s)
 			}
 			else
 			{
-			if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
+			if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase)
 				{
 				s->his.h=bsearch_node(t->n.nd, maxbase - t->shift);
 				while(s->his.h->next && s->his.h->time==s->his.h->next->time) s->his.h=s->his.h->next;
@@ -888,7 +898,7 @@ while(s)
 			case ST_FALL:
 				totaltraces++;
 				break;
-				
+
 			case ST_HIGH:
 				totaltraces++;
 				if((chval2=chval))
@@ -954,7 +964,7 @@ while(s)
 				totaltraces++;
 				s->search_result=1;
 				break;
-		
+
 			case ST_STRING:
 				totaltraces++;
 				if(s->string)
@@ -987,7 +997,7 @@ if(totaltraces)
 	{
 	if(GLOBALS->strace_ctx->logical_mutex[0])	/* and */
 		{
-		if(totaltraces==passcount) break;		
+		if(totaltraces==passcount) break;
 		}
 	else
 	if(GLOBALS->strace_ctx->logical_mutex[1])	/* or */
@@ -1034,13 +1044,13 @@ if(is_last_iteration)
 		                if((GLOBALS->tims.start&1)&&(GLOBALS->tims.end&1)) middle++;
 		                }
 		                else
-		                { 
+		                {
 		                middle=GLOBALS->tims.marker;
 		                }
-	
+
 		GLOBALS->tims.start=time_trunc(middle-(width/2));
 		if(GLOBALS->tims.start+width>GLOBALS->tims.last) GLOBALS->tims.start=GLOBALS->tims.last-width;
-		if(GLOBALS->tims.start<GLOBALS->tims.first) GLOBALS->tims.start=GLOBALS->tims.first;  
+		if(GLOBALS->tims.start<GLOBALS->tims.first) GLOBALS->tims.start=GLOBALS->tims.first;
 		GTK_ADJUSTMENT(GLOBALS->wave_hslider)->value=GLOBALS->tims.timecache=GLOBALS->tims.start;
 		}
 
@@ -1097,7 +1107,7 @@ while(s)
 		while(h->time==h->next->time) h=h->next;
 		if((whichpass)||(notfirst)) h=h->next;
 		if(!h) return(MAX_HISTENT_TIME);
-		utt=strace_adjust(h->time,GLOBALS->shift_timebase); tt=utt;		
+		utt=strace_adjust(h->time,GLOBALS->shift_timebase); tt=utt;
 		if(tt < maxbase) maxbase=tt;
 		}
 		else
@@ -1125,19 +1135,19 @@ while(s)
 	t=s->trace;
 	s->search_result=0;	/* explicitly must set this */
 	GLOBALS->shift_timebase=t->shift;
-	
+
 	if((!t->vector)&&(!(t->n.nd->extvals)))
 		{
-		if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
+		if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase)
 			{
 			s->his.h=bsearch_node(t->n.nd, maxbase - t->shift);
 			while(s->his.h->next && s->his.h->time==s->his.h->next->time) s->his.h=s->his.h->next;
 			}
-		if(t->flags&TR_INVERT)  
+		if(t->flags&TR_INVERT)
                 	{
                         str[0]=AN_STR_INV[s->his.h->v.h_val];
                         }
-                        else   
+                        else
                         {
                         str[0]=AN_STR[s->his.h->v.h_val];
                         }
@@ -1147,16 +1157,16 @@ while(s)
 			{
 			case ST_DC:
 				break;
-				
+
 			case ST_HIGH:
 				totaltraces++;
-				if((str[0]=='1')||(str[0]=='h')||(str[0]=='H')) s->search_result=1;	
+				if((str[0]=='1')||(str[0]=='h')||(str[0]=='H')) s->search_result=1;
 				break;
 
 			case ST_RISE:
 				totaltraces++;
-				if(((str[0]=='1')||(str[0]=='h')||(str[0]=='H'))&&(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)==maxbase)) 
-					s->search_result=1;	
+				if(((str[0]=='1')||(str[0]=='h')||(str[0]=='H'))&&(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)==maxbase))
+					s->search_result=1;
 				break;
 
 			case ST_LOW:
@@ -1174,7 +1184,7 @@ while(s)
 				totaltraces++;
 				if((str[0]=='z')||(str[0]=='Z'))
  					s->search_result=1;
-				break;				
+				break;
 
 			case ST_X:
 				totaltraces++;
@@ -1185,7 +1195,7 @@ while(s)
 				totaltraces++;
 				if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)==maxbase)s->search_result=1;
 				break;
-		
+
 			case ST_STRING:
 				totaltraces++;
 				if(s->string)
@@ -1206,7 +1216,7 @@ while(s)
 
 		if(t->vector)
 			{
-			if(strace_adjust(s->his.v->time,GLOBALS->shift_timebase)!=maxbase) 
+			if(strace_adjust(s->his.v->time,GLOBALS->shift_timebase)!=maxbase)
 				{
 				s->his.v=bsearch_vector(t->n.vec, maxbase - t->shift);
 				while(s->his.v->next && s->his.v->time==s->his.v->next->time) s->his.v=s->his.v->next;
@@ -1215,7 +1225,7 @@ while(s)
 			}
 			else
 			{
-			if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
+			if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase)
 				{
 				s->his.h=bsearch_node(t->n.nd, maxbase - t->shift);
 				while(s->his.h->next && s->his.h->time==s->his.h->next->time) s->his.h=s->his.h->next;
@@ -1256,7 +1266,7 @@ while(s)
 			case ST_FALL:
 				totaltraces++;
 				break;
-				
+
 			case ST_HIGH:
 				totaltraces++;
 				if((chval2=chval))
@@ -1323,7 +1333,7 @@ while(s)
 				if(strace_adjust(s->his.v->time,GLOBALS->shift_timebase)==maxbase)
 					s->search_result=1;
 				break;
-		
+
 			case ST_STRING:
 				totaltraces++;
 				if(s->string)
@@ -1356,7 +1366,7 @@ if(totaltraces)
 	{
 	if(GLOBALS->strace_ctx->logical_mutex[0])	/* and */
 		{
-		if(totaltraces==passcount) break;		
+		if(totaltraces==passcount) break;
 		}
 	else
 	if(GLOBALS->strace_ctx->logical_mutex[1])	/* or */
@@ -1574,7 +1584,7 @@ GLOBALS->strace_ctx->straces = strace_cache;
 /*
  * printf to memory..
  */
-  
+
 int mprintf(const char *fmt, ... )
 {
 int len;
@@ -1582,13 +1592,13 @@ int rc;
 va_list args;
 struct mprintf_buff_t *bt = (struct mprintf_buff_t *)calloc_2(1, sizeof(struct mprintf_buff_t));
 char buff[65537];
-                                
+
 va_start(args, fmt);
 rc=vsprintf(buff, fmt, args);
 len = strlen(buff);
 bt->str = malloc_2(len+1);
 strcpy(bt->str, buff);
-                 
+
 if(!GLOBALS->strace_ctx->mprintf_buff_current)
         {
         GLOBALS->strace_ctx->mprintf_buff_head = GLOBALS->strace_ctx->mprintf_buff_current = bt;
@@ -1599,7 +1609,7 @@ if(!GLOBALS->strace_ctx->mprintf_buff_current)
         GLOBALS->strace_ctx->mprintf_buff_current = bt;
         }
 
-va_end(args);                        
+va_end(args);
 return(rc);
 }
 
@@ -1611,8 +1621,8 @@ void delete_mprintf(void)
 if(GLOBALS->strace_ctx->mprintf_buff_head)
 	{
 	struct mprintf_buff_t *mb = GLOBALS->strace_ctx->mprintf_buff_head;
-	struct mprintf_buff_t *mbt;		
-		
+	struct mprintf_buff_t *mbt;
+
 	while(mb)
 		{
 		free_2(mb->str);
@@ -1667,7 +1677,7 @@ if(GLOBALS->strace_ctx->timearray)
 			}
 		prevshift=t->shift;
 
-		if(!(t->flags&(TR_BLANK|TR_ANALOG_BLANK_STRETCH)))	
+		if(!(t->flags&(TR_BLANK|TR_ANALOG_BLANK_STRETCH)))
 			{
 			if(t->vector)
 				{
