@@ -1,4 +1,4 @@
-/* 
+/*
  * Copyright (c) Tristan Gingold and Tony Bybell 2006-2014.
  *
  * This program is free software; you can redistribute it and/or
@@ -54,10 +54,10 @@ struct autocoalesce_free_list *at;
 while(GLOBALS->afl_treesearch_gtk2_c_1)
 	{
 	if(GLOBALS->afl_treesearch_gtk2_c_1->name) free_2(GLOBALS->afl_treesearch_gtk2_c_1->name);
-	at = GLOBALS->afl_treesearch_gtk2_c_1->next;			
+	at = GLOBALS->afl_treesearch_gtk2_c_1->next;
 	free_2(GLOBALS->afl_treesearch_gtk2_c_1);
 	GLOBALS->afl_treesearch_gtk2_c_1 = at;
-	}	
+	}
 }
 
 
@@ -147,7 +147,7 @@ fill_sig_store (void)
 	unsigned int varxt;
 	char *varxt_pnt;
 
-	if(i < 0) 
+	if(i < 0)
 		{
 		t_prev = NULL;
 		continue;
@@ -216,9 +216,9 @@ fill_sig_store (void)
 
 	wrexm = 0;
 	if 	(
-		(GLOBALS->filter_str_treesearch_gtk2_c_1 == NULL) || 
+		(GLOBALS->filter_str_treesearch_gtk2_c_1 == NULL) ||
 		((!GLOBALS->filter_noregex_treesearch_gtk2_c_1) && (wrexm = wave_regex_match(t->name, WAVE_REGEX_TREE)) && (!GLOBALS->filter_matlen_treesearch_gtk2_c_1)) ||
-		(GLOBALS->filter_matlen_treesearch_gtk2_c_1 && (GLOBALS->filter_typ_treesearch_gtk2_c_1 == vardir) && 
+		(GLOBALS->filter_matlen_treesearch_gtk2_c_1 && (GLOBALS->filter_typ_treesearch_gtk2_c_1 == vardir) &&
 			(wrexm || (wrexm = wave_regex_match(t->name, WAVE_REGEX_TREE)))	)
 		)
       		{
@@ -228,7 +228,7 @@ fill_sig_store (void)
 			gtk_list_store_set (GLOBALS->sig_store_treesearch_gtk2_c_1, &iter,
 				    NAME_COLUMN, s,
 				    TREE_COLUMN, t,
-				    TYPE_COLUMN, 
+				    TYPE_COLUMN,
 						(((GLOBALS->supplemental_datatypes_encountered) && (!GLOBALS->supplemental_vartypes_encountered)) ?
 							(varxt ? varxt_pnt : vardatatype_strings[vardt]) : vartype_strings[vartype]),
 				    DIR_COLUMN, vardir_strings[vardir],
@@ -245,12 +245,12 @@ fill_sig_store (void)
 			struct autocoalesce_free_list *a = calloc_2(1, sizeof(struct autocoalesce_free_list));
 			a->name = s;
 			a->next = GLOBALS->afl_treesearch_gtk2_c_1;
-			GLOBALS->afl_treesearch_gtk2_c_1 = a;			
+			GLOBALS->afl_treesearch_gtk2_c_1 = a;
 
 			gtk_list_store_set (GLOBALS->sig_store_treesearch_gtk2_c_1, &iter,
 				    NAME_COLUMN, s,
 				    TREE_COLUMN, t,
-				    TYPE_COLUMN, 
+				    TYPE_COLUMN,
 						(((GLOBALS->supplemental_datatypes_encountered) && (!GLOBALS->supplemental_vartypes_encountered)) ?
 							(varxt ? varxt_pnt : vardatatype_strings[vardt]) : vartype_strings[vartype]),
 				    DIR_COLUMN, vardir_strings[vardir],
@@ -283,7 +283,7 @@ if(node)
 		{
 		GtkCTree *ctree = GLOBALS->ctree_main;
 		GtkCTreeNode *n = gctr->children;
-	
+
 		gtk_clist_freeze(GTK_CLIST(ctree));
 
 		while(n)
@@ -299,10 +299,10 @@ if(node)
 					maketree2(n, t, 0, n);
 					}
 				}
-	
+
 			n = GTK_CTREE_NODE_NEXT(n);
 			}
-	
+
 		gtk_clist_thaw(GTK_CLIST(ctree));
 		}
 	}
@@ -321,12 +321,12 @@ int force_open_tree_node(char *name, int keep_path_nodes_open, struct tree **t_p
     GtkCTreeNode *node = GLOBALS->any_tree_node;
     GtkCTreeRow *gctr = GTK_CTREE_ROW(node);
     int depth = 1;
-    
+
     strcpy(namecache, name);
     while(gctr->parent)	{
       node = gctr->parent;
       gctr = GTK_CTREE_ROW(node);
-    } 
+    }
     for(;;) {
       struct tree *t = gctr->row.data;
       if(t_pnt) { *t_pnt = t; }
@@ -348,12 +348,12 @@ int force_open_tree_node(char *name, int keep_path_nodes_open, struct tree **t_p
 	  exp1[i--] = 1;
 	  /* now work backwards up to parent getting the node open/close history*/
 	  gctr = GTK_CTREE_ROW(node);
-	  while(gctr->parent) {        
+	  while(gctr->parent) {
 	    node = gctr->parent;
 	    gctr = GTK_CTREE_ROW(node);
 	    nodehist[i] = node;
 	    exp1[i--] = gctr->expanded || (keep_path_nodes_open != 0);
-	  }        
+	  }
 	  gtk_clist_freeze(GTK_CLIST(ctree));
 	  /* fully expand down */
 	  for(i=0;i<depth;i++) {
@@ -416,7 +416,7 @@ if(t->right)
 	}
 }
 
-static void generic_tree_expand_collapse_callback(int is_expand, GtkCTreeNode *node) 
+static void generic_tree_expand_collapse_callback(int is_expand, GtkCTreeNode *node)
 {
 GtkCTreeRow **gctr;
 int depth, i;
@@ -490,6 +490,9 @@ if(is_expand)
 
 static void tree_expand_callback(GtkCTree *ctree, GtkCTreeNode *node, gpointer user_data)
 {
+(void)ctree;
+(void)user_data;
+
 create_sst_nodes_if_necessary(node);
 generic_tree_expand_collapse_callback(1, node);
 #ifdef WAVE_ALLOW_QUARTZ_FLUSH_WORKAROUND
@@ -500,9 +503,12 @@ gtk_widget_show(GTK_WIDGET(GLOBALS->tree_treesearch_gtk2_c_1));
 #endif
 #endif
 }
- 
-static void tree_collapse_callback(GtkCTree *ctree, GtkCTreeNode *node, gpointer user_data) 
+
+static void tree_collapse_callback(GtkCTree *ctree, GtkCTreeNode *node, gpointer user_data)
 {
+(void)ctree;
+(void)user_data;
+
 generic_tree_expand_collapse_callback(0, node);
 #ifdef WAVE_ALLOW_QUARTZ_FLUSH_WORKAROUND
 #ifdef MAC_INTEGRATION
@@ -533,7 +539,7 @@ if(ctree)
 		{
 		node = gctr->parent;
 		gctr = GTK_CTREE_ROW(node);
-		} 
+		}
 
 	for(;;)
 		{
@@ -591,6 +597,11 @@ if(ctree)
 static void select_row_callback(GtkWidget *widget, gint row, gint column,
         GdkEventButton *event, gpointer data)
 {
+(void)widget;
+(void)column;
+(void)event;
+(void)data;
+
 struct tree *t;
 GtkCTreeNode* node = gtk_ctree_node_nth(GLOBALS->ctree_main, row);
 
@@ -604,17 +615,17 @@ if(node)
 
 	hier_suffix[0] = GLOBALS->hier_delimeter;
 	hier_suffix[1] = 0;
-                
+
 	depth = GTK_CTREE_ROW(node)->level;
 	gctr = wave_alloca(depth * sizeof(GtkCTreeRow *));
-         
+
 	for(i=depth-1;i>=0;i--)
 	        {
 	        gctr[i] = GTK_CTREE_ROW(node);
 	        t = gctr[i]->row.data;
 	        len += (strlen(t->name) + 1);
 	        node = gctr[i]->parent;
-	        }        
+	        }
 
 	tstring = wave_alloca(len);
 	memset(tstring, 0, len);
@@ -644,6 +655,11 @@ DEBUG(printf("TS: %08x %s\n",t,t->name));
 static void unselect_row_callback(GtkWidget *widget, gint row, gint column,
         GdkEventButton *event, gpointer data)
 {
+(void)widget;
+(void)column;
+(void)event;
+(void)data;
+
 struct tree *t;
 
 if(GLOBALS->selected_hierarchy_name)
@@ -669,6 +685,8 @@ DEBUG(printf("TU: %08x %s\n",t,t->name));
 static
 gboolean filter_edit_cb (GtkWidget *widget, GdkEventKey *ev, gpointer *data)
 {
+(void)data;
+
   /* Maybe this test is too strong ?  */
   if (ev->keyval == GDK_Return)
     {
@@ -710,7 +728,7 @@ gboolean filter_edit_cb (GtkWidget *widget, GdkEventKey *ev, gpointer *data)
 						GLOBALS->filter_noregex_treesearch_gtk2_c_1 = 1;
 						}
 					}
-				}			
+				}
 			}
 		}
 
@@ -759,6 +777,9 @@ return(GLOBALS->is_active_treesearch_gtk2_c_6);
 
 static void enter_callback_e(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)widget;
+(void)nothing;
+
   G_CONST_RETURN gchar *entry_text;
   int len;
   entry_text = gtk_entry_get_text(GTK_ENTRY(GLOBALS->entry_a_treesearch_gtk2_c_2));
@@ -776,6 +797,9 @@ static void enter_callback_e(GtkWidget *widget, GtkWidget *nothing)
 
 static void destroy_callback_e(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)widget;
+(void)nothing;
+
   DEBUG(printf("Entry Cancel\n"));
   GLOBALS->entrybox_text_local_treesearch_gtk2_c_3=NULL;
   wave_gtk_grab_remove(GLOBALS->window1_treesearch_gtk2_c_3);
@@ -849,7 +873,7 @@ return(t);
 /* Get the lowest signal from T.  */
 struct tree *fetchlow(struct tree *t)
 {
-if(t->child) 
+if(t->child)
 	{
 	t=t->child;
 
@@ -892,7 +916,7 @@ if(t)
 		}
 		else
 		{
-		add_vector_range(NULL, fetchlow(t)->t_which, 
+		add_vector_range(NULL, fetchlow(t)->t_which,
 			fetchhigh(t)->t_which, direction);
 		}
 	}
@@ -907,6 +931,9 @@ bundle_cleanup_foreach (GtkTreeModel *model,
 			GtkTreeIter *iter,
 			gpointer data)
 {
+(void)path;
+(void)data;
+
   struct tree *sel;
 
   /* Extract the tree.  */
@@ -914,10 +941,10 @@ bundle_cleanup_foreach (GtkTreeModel *model,
 
   if(!sel) return;
 
-if(GLOBALS->entrybox_text_local_treesearch_gtk2_c_3) 
+if(GLOBALS->entrybox_text_local_treesearch_gtk2_c_3)
         {
         char *efix;
- 
+
 	if(!strlen(GLOBALS->entrybox_text_local_treesearch_gtk2_c_3))
 		{
 	        DEBUG(printf("Bundle name is not specified--recursing into hierarchy.\n"));
@@ -934,11 +961,11 @@ if(GLOBALS->entrybox_text_local_treesearch_gtk2_c_3)
 	                        }
 	                efix++;
 	                }
-	 
+
 	        DEBUG(printf("Bundle name is: %s\n",GLOBALS->entrybox_text_local_treesearch_gtk2_c_3));
-	        add_vector_range(GLOBALS->entrybox_text_local_treesearch_gtk2_c_3, 
+	        add_vector_range(GLOBALS->entrybox_text_local_treesearch_gtk2_c_3,
 				fetchlow(sel)->t_which,
-				fetchhigh(sel)->t_which, 
+				fetchhigh(sel)->t_which,
 				GLOBALS->bundle_direction_treesearch_gtk2_c_3);
 		}
         free_2(GLOBALS->entrybox_text_local_treesearch_gtk2_c_3);
@@ -952,7 +979,10 @@ if(GLOBALS->entrybox_text_local_treesearch_gtk2_c_3)
 
 static void
 bundle_cleanup(GtkWidget *widget, gpointer data)
-{ 
+{
+(void)widget;
+(void)data;
+
   gtk_tree_selection_selected_foreach
     (GLOBALS->sig_selection_treesearch_gtk2_c_1, &bundle_cleanup_foreach, NULL);
 
@@ -960,7 +990,7 @@ MaxSignalLength();
 signalarea_configure_event(GLOBALS->signalarea, NULL);
 wavearea_configure_event(GLOBALS->wavearea, NULL);
 }
- 
+
 static void
 bundle_callback_generic(void)
 {
@@ -981,6 +1011,9 @@ bundle_callback_generic(void)
 static void
 bundle_callback_up(GtkWidget *widget, gpointer data)
 {
+(void)widget;
+(void)data;
+
 GLOBALS->bundle_direction_treesearch_gtk2_c_3=0;
 bundle_callback_generic();
 }
@@ -988,6 +1021,9 @@ bundle_callback_generic();
 static void
 bundle_callback_down(GtkWidget *widget, gpointer data)
 {
+(void)widget;
+(void)data;
+
 GLOBALS->bundle_direction_treesearch_gtk2_c_3=1;
 bundle_callback_generic();
 }
@@ -1004,6 +1040,9 @@ sig_selection_foreach (GtkTreeModel *model,
 		       GtkTreeIter *iter,
 		       gpointer data)
 {
+(void)path;
+(void)data;
+
   struct tree *sel;
   /* const enum cb_action action = (enum cb_action)data; */
   int i;
@@ -1021,7 +1060,7 @@ sig_selection_foreach (GtkTreeModel *model,
   for(i=low;i<=high;i++)
         {
 	int len;
-        struct symbol *s, *t;  
+        struct symbol *s, *t;
         s=GLOBALS->facs[i];
 	t=s->vec_root;
 	if((t)&&(GLOBALS->autocoalesce))
@@ -1040,7 +1079,7 @@ sig_selection_foreach (GtkTreeModel *model,
 		}
 		else
 		{
-	        AddNodeUnroll(s->n, NULL);  
+	        AddNodeUnroll(s->n, NULL);
 		}
         }
 }
@@ -1051,7 +1090,7 @@ sig_selection_foreach_finalize (gpointer data)
  const enum cb_action action = (enum cb_action)data;
 
  if (action == ACTION_REPLACE || action == ACTION_INSERT || action == ACTION_PREPEND)
-   { 
+   {
      Trptr tfirst=NULL, tlast=NULL;
      Trptr t;
      Trptr *tp = NULL;
@@ -1095,7 +1134,7 @@ sig_selection_foreach_finalize (gpointer data)
      GLOBALS->traces.buffercount=GLOBALS->tcache_treesearch_gtk2_c_2.buffercount;
      GLOBALS->traces.buffer=GLOBALS->tcache_treesearch_gtk2_c_2.buffer;
      GLOBALS->traces.bufferlast=GLOBALS->tcache_treesearch_gtk2_c_2.bufferlast;
-     
+
      if (action == ACTION_REPLACE)
        {
 	for(it=0;it<numhigh;it++)
@@ -1135,6 +1174,9 @@ sig_selection_foreach_preload_lx2
 		       GtkTreeIter *iter,
 		       gpointer data)
 {
+(void)path;
+(void)data;
+
   struct tree *sel;
   /* const enum cb_action action = (enum cb_action)data; */
   int i;
@@ -1151,7 +1193,7 @@ sig_selection_foreach_preload_lx2
   /* If signals are vectors, coalesces vectors if so.  */
   for(i=low;i<=high;i++)
         {
-        struct symbol *s;  
+        struct symbol *s;
         s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
@@ -1234,6 +1276,8 @@ action_callback(enum cb_action action)
 
 static void insert_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)nothing;
+
   set_window_busy(widget);
   action_callback (ACTION_INSERT);
   set_window_idle(widget);
@@ -1241,6 +1285,8 @@ static void insert_callback(GtkWidget *widget, GtkWidget *nothing)
 
 static void replace_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)nothing;
+
   set_window_busy(widget);
   action_callback (ACTION_REPLACE);
   set_window_idle(widget);
@@ -1248,6 +1294,8 @@ static void replace_callback(GtkWidget *widget, GtkWidget *nothing)
 
 static void ok_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)nothing;
+
   set_window_busy(widget);
   action_callback (ACTION_APPEND);
   set_window_idle(widget);
@@ -1256,6 +1304,9 @@ static void ok_callback(GtkWidget *widget, GtkWidget *nothing)
 
 static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)widget;
+(void)nothing;
+
   GLOBALS->is_active_treesearch_gtk2_c_6=0;
   gtk_widget_destroy(GLOBALS->window_treesearch_gtk2_c_12);
   GLOBALS->window_treesearch_gtk2_c_12 = NULL;
@@ -1281,6 +1332,9 @@ static gboolean
                        gboolean          path_currently_selected,
                        gpointer          userdata)
   {
+(void)selection;
+(void)userdata;
+
     GtkTreeIter iter;
 
     if (gtk_tree_model_get_iter(model, &iter, path))
@@ -1314,6 +1368,8 @@ static gboolean
 
 static gint button_press_event_std(GtkWidget *widget, GdkEventButton *event)
 {
+(void)widget;
+
 if(event->type == GDK_2BUTTON_PRESS)
 	{
 	if(GLOBALS->selected_hierarchy_name && GLOBALS->selected_sig_name)
@@ -1370,9 +1426,9 @@ void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
 	goto do_tooltips;
 	}
 
-    if(GLOBALS->is_active_treesearch_gtk2_c_6) 
+    if(GLOBALS->is_active_treesearch_gtk2_c_6)
 	{
-	if(GLOBALS->window_treesearch_gtk2_c_12) 
+	if(GLOBALS->window_treesearch_gtk2_c_12)
 		{
 		gdk_window_raise(GLOBALS->window_treesearch_gtk2_c_12->window);
 		}
@@ -1404,7 +1460,7 @@ do_tooltips:
     GLOBALS->treesearch_gtk2_window_vbox = vbox = gtk_vbox_new (FALSE, 1);
     gtk_widget_show (vbox);
 
-    gtkwave_signal_connect(GTK_OBJECT(vbox), "button_press_event",GTK_SIGNAL_FUNC(hier_top_button_press_event_std), NULL); 
+    gtkwave_signal_connect(GTK_OBJECT(vbox), "button_press_event",GTK_SIGNAL_FUNC(hier_top_button_press_event_std), NULL);
 
     vpan = gtk_vpaned_new ();
     gtk_widget_show (vpan);
@@ -1550,9 +1606,9 @@ do_tooltips:
     gtk_box_pack_start (GTK_BOX (filter_hbox), filter_label, FALSE, FALSE, 1);
 
     GLOBALS->filter_entry = gtk_entry_new ();
-    if(GLOBALS->filter_str_treesearch_gtk2_c_1) 
-	{ 
-	gtk_entry_set_text(GTK_ENTRY(GLOBALS->filter_entry), GLOBALS->filter_str_treesearch_gtk2_c_1); 
+    if(GLOBALS->filter_str_treesearch_gtk2_c_1)
+	{
+	gtk_entry_set_text(GTK_ENTRY(GLOBALS->filter_entry), GLOBALS->filter_str_treesearch_gtk2_c_1);
 	}
 
     gtk_widget_show (GLOBALS->filter_entry);
@@ -1592,7 +1648,7 @@ do_tooltips:
     gtk_container_border_width (GTK_CONTAINER (button1), 3);
     gtkwave_signal_connect_object (GTK_OBJECT (button1), "clicked",GTK_SIGNAL_FUNC(ok_callback),GTK_OBJECT (GLOBALS->window_treesearch_gtk2_c_12));
     gtk_widget_show (button1);
-    gtk_tooltips_set_tip_2(tooltips, button1, 
+    gtk_tooltips_set_tip_2(tooltips, button1,
 		"Add selected signal hierarchy to end of the display on the main window.",NULL);
 
     gtk_box_pack_start (GTK_BOX (hbox), button1, TRUE, FALSE, 0);
@@ -1601,7 +1657,7 @@ do_tooltips:
     gtk_container_border_width (GTK_CONTAINER (button2), 3);
     gtkwave_signal_connect_object (GTK_OBJECT (button2), "clicked",GTK_SIGNAL_FUNC(insert_callback),GTK_OBJECT (GLOBALS->window_treesearch_gtk2_c_12));
     gtk_widget_show (button2);
-    gtk_tooltips_set_tip_2(tooltips, button2, 
+    gtk_tooltips_set_tip_2(tooltips, button2,
 		"Add selected signal hierarchy after last highlighted signal on the main window.",NULL);
     gtk_box_pack_start (GTK_BOX (hbox), button2, TRUE, FALSE, 0);
 
@@ -1611,7 +1667,7 @@ do_tooltips:
     	gtk_container_border_width (GTK_CONTAINER (button3), 3);
     	gtkwave_signal_connect_object (GTK_OBJECT (button3), "clicked",GTK_SIGNAL_FUNC(bundle_callback_up),GTK_OBJECT (GLOBALS->window_treesearch_gtk2_c_12));
     	gtk_widget_show (button3);
-    	gtk_tooltips_set_tip_2(tooltips, button3, 
+    	gtk_tooltips_set_tip_2(tooltips, button3,
 		"Bundle selected signal hierarchy into a single bit "
 		"vector with the topmost signal as the LSB and the "
 		"lowest as the MSB.  Entering a zero length bundle "
@@ -1625,7 +1681,7 @@ do_tooltips:
     	gtk_container_border_width (GTK_CONTAINER (button3a), 3);
     	gtkwave_signal_connect_object (GTK_OBJECT (button3a), "clicked",GTK_SIGNAL_FUNC(bundle_callback_down),GTK_OBJECT (GLOBALS->window_treesearch_gtk2_c_12));
     	gtk_widget_show (button3a);
-    	gtk_tooltips_set_tip_2(tooltips, button3a, 
+    	gtk_tooltips_set_tip_2(tooltips, button3a,
 		"Bundle selected signal hierarchy into a single bit "
 		"vector with the topmost signal as the MSB and the "
 		"lowest as the LSB.  Entering a zero length bundle "
@@ -1640,14 +1696,14 @@ do_tooltips:
     gtk_container_border_width (GTK_CONTAINER (button4), 3);
     gtkwave_signal_connect_object (GTK_OBJECT (button4), "clicked",GTK_SIGNAL_FUNC(replace_callback),GTK_OBJECT (GLOBALS->window_treesearch_gtk2_c_12));
     gtk_widget_show (button4);
-    gtk_tooltips_set_tip_2(tooltips, button4, 
+    gtk_tooltips_set_tip_2(tooltips, button4,
 		"Replace highlighted signals on the main window with signals selected above.",NULL);
     gtk_box_pack_start (GTK_BOX (hbox), button4, TRUE, FALSE, 0);
 
     button5 = gtk_button_new_with_label (" Exit ");
     gtk_container_border_width (GTK_CONTAINER (button5), 3);
     gtkwave_signal_connect_object (GTK_OBJECT (button5), "clicked",GTK_SIGNAL_FUNC(destroy_callback),GTK_OBJECT (GLOBALS->window_treesearch_gtk2_c_12));
-    gtk_tooltips_set_tip_2(tooltips, button5, 
+    gtk_tooltips_set_tip_2(tooltips, button5,
 		"Do nothing and return to the main window.",NULL);
     gtk_widget_show (button5);
     gtk_box_pack_start (GTK_BOX (hbox), button5, TRUE, FALSE, 0);
@@ -1665,6 +1721,8 @@ do_tooltips:
  */
 GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
 {
+(void)title;
+
     GtkWidget *scrolled_win, *sig_scroll_win;
     GtkWidget *hbox;
     GtkWidget *button1, *button2, *button3, *button3a, *button4;
@@ -1684,13 +1742,13 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
     vbox = gtk_vbox_new (FALSE, 1);
     gtk_widget_show (vbox);
 
-    gtkwave_signal_connect(GTK_OBJECT(vbox), "button_press_event",GTK_SIGNAL_FUNC(hier_top_button_press_event_std), NULL); 
+    gtkwave_signal_connect(GTK_OBJECT(vbox), "button_press_event",GTK_SIGNAL_FUNC(hier_top_button_press_event_std), NULL);
 
     vpan = gtk_vpaned_new (); /* GLOBALS->sst_vpaned is to be used to clone position over during reload */
     GLOBALS->sst_vpaned = (GtkPaned *)vpan;
     if(GLOBALS->vpanedwindow_size_cache)
 	{
-	gtk_paned_set_position(GTK_PANED(GLOBALS->sst_vpaned), GLOBALS->vpanedwindow_size_cache);    
+	gtk_paned_set_position(GTK_PANED(GLOBALS->sst_vpaned), GLOBALS->vpanedwindow_size_cache);
 	GLOBALS->vpanedwindow_size_cache = 0;
 	}
     gtk_widget_show (vpan);
@@ -1869,7 +1927,7 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
     gtk_container_border_width (GTK_CONTAINER (button1), 3);
     gtkwave_signal_connect_object (GTK_OBJECT (button1), "clicked", GTK_SIGNAL_FUNC(ok_callback), GTK_OBJECT (GLOBALS->gtk2_tree_frame));
     gtk_widget_show (button1);
-    gtk_tooltips_set_tip_2(tooltips, button1, 
+    gtk_tooltips_set_tip_2(tooltips, button1,
 		"Add selected signal hierarchy to end of the display on the main window.",NULL);
 
     gtk_box_pack_start (GTK_BOX (hbox), button1, TRUE, FALSE, 0);
@@ -1878,7 +1936,7 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
     gtk_container_border_width (GTK_CONTAINER (button2), 3);
     gtkwave_signal_connect_object (GTK_OBJECT (button2), "clicked", GTK_SIGNAL_FUNC(insert_callback), GTK_OBJECT (GLOBALS->gtk2_tree_frame));
     gtk_widget_show (button2);
-    gtk_tooltips_set_tip_2(tooltips, button2, 
+    gtk_tooltips_set_tip_2(tooltips, button2,
 		"Add selected signal hierarchy after last highlighted signal on the main window.",NULL);
     gtk_box_pack_start (GTK_BOX (hbox), button2, TRUE, FALSE, 0);
 
@@ -1888,7 +1946,7 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
     	gtk_container_border_width (GTK_CONTAINER (button3), 3);
     	gtkwave_signal_connect_object (GTK_OBJECT (button3), "clicked", GTK_SIGNAL_FUNC(bundle_callback_up), GTK_OBJECT (GLOBALS->gtk2_tree_frame));
     	gtk_widget_show (button3);
-    	gtk_tooltips_set_tip_2(tooltips, button3, 
+    	gtk_tooltips_set_tip_2(tooltips, button3,
 		"Bundle selected signal hierarchy into a single bit "
 		"vector with the topmost signal as the LSB and the "
 		"lowest as the MSB.  Entering a zero length bundle "
@@ -1902,7 +1960,7 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
     	gtk_container_border_width (GTK_CONTAINER (button3a), 3);
     	gtkwave_signal_connect_object (GTK_OBJECT (button3a), "clicked", GTK_SIGNAL_FUNC(bundle_callback_down), GTK_OBJECT (GLOBALS->gtk2_tree_frame));
     	gtk_widget_show (button3a);
-    	gtk_tooltips_set_tip_2(tooltips, button3a, 
+    	gtk_tooltips_set_tip_2(tooltips, button3a,
 		"Bundle selected signal hierarchy into a single bit "
 		"vector with the topmost signal as the MSB and the "
 		"lowest as the LSB.  Entering a zero length bundle "
@@ -1917,7 +1975,7 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
     gtk_container_border_width (GTK_CONTAINER (button4), 3);
     gtkwave_signal_connect_object (GTK_OBJECT (button4), "clicked", GTK_SIGNAL_FUNC(replace_callback), GTK_OBJECT (GLOBALS->gtk2_tree_frame));
     gtk_widget_show (button4);
-    gtk_tooltips_set_tip_2(tooltips, button4, 
+    gtk_tooltips_set_tip_2(tooltips, button4,
 		"Replace highlighted signals on the main window with signals selected above.",NULL);
     gtk_box_pack_start (GTK_BOX (hbox), button4, TRUE, FALSE, 0);
 
@@ -1939,6 +1997,8 @@ static void DNDBeginCB(
 	GtkWidget *widget, GdkDragContext *dc, gpointer data
 )
 {
+(void)data;
+
         if((widget == NULL) || (dc == NULL))
 		return;
 
@@ -1965,6 +2025,10 @@ static void DNDEndCB_2(
 	GtkWidget *widget, GdkDragContext *dc, gpointer data
 )
 {
+(void)widget;
+(void)dc;
+(void)data;
+
 Trptr t;
 int trwhich, trtarget;
 GdkModifierType state;
@@ -1997,7 +2061,7 @@ else
 
 
 if((t=GLOBALS->traces.first))
-        {       
+        {
         while(t)
                 {
                 t->flags&=~TR_HIGHLIGHT;
@@ -2007,8 +2071,8 @@ if((t=GLOBALS->traces.first))
         wavearea_configure_event(GLOBALS->wavearea, NULL);
 	}
 
-trtarget = ((int)y / (int)GLOBALS->fontheight) - 2; 
-if(trtarget < 0) 
+trtarget = ((int)y / (int)GLOBALS->fontheight) - 2;
+if(trtarget < 0)
 	{
 	Trptr tp = GLOBALS->topmost_trace ? GivePrevTrace(GLOBALS->topmost_trace): NULL;
 	trtarget = 0;
@@ -2086,13 +2150,13 @@ static void DNDEndCB(
 	GtkWidget *widget, GdkDragContext *dc, gpointer data
 )
 {
-if((widget == NULL) || (dc == NULL)) 
+if((widget == NULL) || (dc == NULL))
 	{
 	GLOBALS->tree_dnd_begin = VIEW_DRAG_INACTIVE;
 	return;
 	}
 
-if(GLOBALS->tree_dnd_begin == VIEW_DRAG_INACTIVE) 
+if(GLOBALS->tree_dnd_begin == VIEW_DRAG_INACTIVE)
 	{
 	return; /* to keep cut and paste in signalwindow from conflicting */
 	}
@@ -2118,7 +2182,7 @@ GLOBALS->tree_dnd_begin = VIEW_DRAG_INACTIVE;
 
 
 /*
- *	DND "drag_motion" handler, this is called whenever the 
+ *	DND "drag_motion" handler, this is called whenever the
  *	pointer is dragging over the target widget.
  */
 static gboolean DNDDragMotionCB(
@@ -2127,6 +2191,10 @@ static gboolean DNDDragMotionCB(
         gpointer data
 )
 {
+(void)x; 
+(void)y;
+(void)data;
+
 	gboolean same_widget;
 	GdkDragAction suggested_action;
 	GtkWidget *src_widget, *tar_widget;
@@ -2193,6 +2261,11 @@ static void DNDDataRequestCB(
 	gpointer data
 )
 {
+(void)dc;
+(void)info;
+(void)t;
+(void)data;
+
 int upd = 0;
 GLOBALS->tree_dnd_requested = 1;  /* indicate that a request for data occurred... */
 
@@ -2217,7 +2290,7 @@ else if(widget == GLOBALS->signalarea)
 			int textlen = strlen(text);
 			int text2len = strlen(text2);
 			char *pnt = calloc_2(1, textlen + text2len + 1);
-			
+
 			memcpy(pnt, text, textlen);
 			memcpy(pnt + textlen, text2, text2len);
 
@@ -2263,6 +2336,10 @@ static void DNDDataReceivedCB(
 	GtkWidget *widget, GdkDragContext *dc,
 	gint x, gint y, GtkSelectionData *selection_data,
 	guint info, guint t, gpointer data) {
+(void)x;
+(void)y;
+(void)t;
+
     gboolean same;
     GtkWidget *source_widget;
 
@@ -2372,8 +2449,12 @@ static void DNDDataDeleteCB(
 	GtkWidget *widget, GdkDragContext *dc, gpointer data
 )
 {
+(void)widget;
+(void)dc;
+(void)data;
+
 /* nothing */
-}  
+}
 
 
 /***********************/
